<?php
namespace backend\controllers;

use Yii;
use yii\web\Controller;
use backend\models\Api;
use yii\helpers\Url;
use backend\models\ResetPasswordForm;

/**
 * Country Controller API
 *
 * @author Budi Irawan <deerawan@gmail.com>
 */
class ApiController extends Controller {
    
    public function beforeAction($action) {
        $this->enableCsrfValidation = false;
        return parent::beforeAction($action);
    }
    public function actionLogin() {
        
        $response = array();
        $user = new Api();
        $error = $user->getStatusCodeMessage();
        $message = '';
            if ((isset($_REQUEST['email']) && isset($_REQUEST['password_hash']))) {
                $loginData = array('email' => $_REQUEST['email'], 'password' => $_REQUEST['password_hash']);
                $result = $user->login($loginData);
                $userID = $result['id'];
                if (isset($userID)) {
                    $pass = Yii::$app->security->validatePassword($_REQUEST['password_hash'], $result['password_hash']);
                    if ($pass) {
                        $response['status'] = "1";
                        $response['user_id'] = $result['id'];
                        $response['message'] = "You have successfully logged in";
                        echo json_encode($response, JSON_PRETTY_PRINT);
                        exit;
                        
                    } else {
                        $response['status'] = "0";
                        $response['message'] = "Invalid email or password.";
                        echo json_encode($response, JSON_PRETTY_PRINT);
                        exit;
                    }
                } else {
                    $response['status'] = "0";
                    $response['message'] = "email does not exist.";
                    echo json_encode($response, JSON_PRETTY_PRINT);
                    exit;
                }
            } else {
                $message = $error[400];
                $response['status'] = "0";
                $response['message'] = $message;
                $response['token'] = '';
                echo json_encode($response, JSON_PRETTY_PRINT);
                exit;
            }
         
    }

    public function actionRegister() {
        $response = array();
        $user = new Api();
        $error = $user->getStatusCodeMessage();
        $message = '';
        if (isset($_REQUEST['email']) && isset($_REQUEST['password_hash']) && isset($_REQUEST['username']) && $_REQUEST['username'] != "" && $_REQUEST['email'] != "" && $_REQUEST['password_hash'] != "") {

            $passwordHash = Yii::$app->security->generatePasswordHash($_REQUEST['password_hash']);
            $authkey = Yii::$app->security->generateRandomString();
            $userData = array('email' => $_REQUEST['email'], 'username' => $_REQUEST['username'],'password_hash' => $passwordHash,'auth_key' => $authkey);

            if ($userID = $user->registerUser($userData)) {
                $response['status'] = "1";
                $response['message'] = "User registered successfully.";
                echo json_encode($response, JSON_PRETTY_PRINT);
                exit;
            }
        } else {
            $response['status'] = "0";
            $response['message'] = "Please fill all required fields";
            echo json_encode($response, JSON_PRETTY_PRINT);
            exit;
        }
    }
    
    public function actionFeedback() {
        $response = array();
        $user = new Api();
        $error = $user->getStatusCodeMessage();
        $message = '';
        if (isset($_REQUEST['user_email']) && isset($_REQUEST['subject']) && isset($_REQUEST['message']) && $_REQUEST['user_email'] != "" && $_REQUEST['subject'] != "" && $_REQUEST['message'] != "") {

            $feedbackData = array('user_email' => $_REQUEST['user_email'], 'subject' => $_REQUEST['subject'], 'message' => $_REQUEST['message']);

            if ($feedbackID = $user->savefeedback($feedbackData)) {
                $response['status'] = "1";
                $response['message'] = "Feedback Save successfully.";
                echo json_encode($response, JSON_PRETTY_PRINT);
                exit;
            }
        } else {
            $response['status'] = "0";
            $response['message'] = "Please fill all required fields";
            echo json_encode($response, JSON_PRETTY_PRINT);
            exit;
        }
    }
    
    public function actionForgotPassword() {
        $response = array();
        $user = new Api();
        
        $this->layout = 'login';
        if (isset($_POST['email']) && $_POST['email'] != '') {
            $user->requestResetPassword1($_POST['email']);
        }
        return $this->render('forgotPassword'); 
    }
    public function actionResetPassword($token) {
        $this->layout = 'login';
        $response = array();
        $user = new Api();
        
        $userCount = (new \yii\db\Query())
                ->from('user')
                ->where(['password_reset_token' => $token])
                ->count();
        if ($userCount <= 0) {
            $response['status'] = "0";
            $response['message'] = "Your password reset link is expired.";
            echo json_encode($response, JSON_PRETTY_PRINT);
            exit;
        }
        try {
            $model = new ResetPasswordForm($token);
        } catch (InvalidParamException $e) {
            throw new BadRequestHttpException($e->getMessage());
        }
        if (isset($_REQUEST['newPassword']) && $_REQUEST['newPassword'] != '') {
            if ($model->resetPassword()) {
                $response['status'] = "0";
                $response['message'] = "Your Password reset successfully. Please login with new password.";
                echo json_encode($response, JSON_PRETTY_PRINT);
                exit;
            }
        }
        return $this->render('resetPassword', [
                    'model' => $model,
        ]);
    }
    
    public function actionRetainedData() {
        $response = array();
        $user = new Api();
         if (isset($_REQUEST['Latitude']) && isset($_REQUEST['Longitude']) && isset($_REQUEST['Latitude']) && $_REQUEST['Longitude'] != "") {
           $retainedData = array('Latitude' => $_REQUEST['Latitude'], 'Longitude' => $_REQUEST['Longitude']);  
           if ($nearLocation = $user->findnearbylocation($retainedData)) {
                $response['status'] = "1";
                $response['message'] = "success";
                $response['nearbylocation'] = $nearLocation;
                echo json_encode($response, JSON_PRETTY_PRINT);
                exit;
            }   
            else {
                $response['status'] = "1";
                $response['message'] = "No result found";
                echo json_encode($response, JSON_PRETTY_PRINT);
                exit;
                }
        } else {
            $response['status'] = "0";
            $response['message'] = "Please fill all required fields";
            echo json_encode($response, JSON_PRETTY_PRINT);
            exit;
        }
    }
    
    public function actionPaypalPayment() {
        $response = array();
        $user = new Api();
        if (isset($_REQUEST['transaction_id']) && isset($_REQUEST['user_id']) && isset($_REQUEST['transaction_id']) && $_REQUEST['user_id'] != "") {
           $paymentData = array('transaction_id' => $_REQUEST['transaction_id'], 'user_id' => $_REQUEST['user_id']);   
           if ($paymentData = $user->savepaymentdata($paymentData)) {
                $response['status'] = "1";
                $response['message'] = "Payment Data Save successfully";
                echo json_encode($response, JSON_PRETTY_PRINT);
                exit;
            } else {
                $response['status'] = "0";
                $response['message'] = "Some error";
                echo json_encode($response, JSON_PRETTY_PRINT);
                exit;
            }
        }
        else {
            $response['status'] = "0";
            $response['message'] = "Please fill all required fields";
            echo json_encode($response, JSON_PRETTY_PRINT);
            exit;
        }
    }
    
//  public function actionChangePassword() {
//        $response = array();
//        $usermodel = new Api();
//        
//        if (isset($_REQUEST['id']) && isset($_REQUEST['oldpassword']) && isset($_REQUEST['newpassword']) && $_REQUEST['id'] != "" && $_REQUEST['oldpassword'] != "" && $_REQUEST['newpassword'] != "")              {
//            $oldpassowrd = array('oldpassword' => $_REQUEST['oldpassword'], 'id' => $_REQUEST['id']);
//            //echo "<pre>";print_r($oldpassowrd);exit;
//            if ($usermodel->checkoldpassword($oldpassowrd)) {
//                echo "hi";exit;
//                
//            } else {
//                $response['status'] = "1";
//                $response['message'] = "old password invalid.";
//                echo json_encode($response, JSON_PRETTY_PRINT);
//                exit;
//            }
//        } else {
//            $response['status'] = "0";
//            $response['message'] = "Please fill all required fields";
//            echo json_encode($response, JSON_PRETTY_PRINT);
//            exit;
//        }
//
//    }
  
}
