<?php

namespace backend\models;

use Yii;
use yii\base\Model;
use yii\data\ActiveDataProvider;
use backend\models\Product;

class ProductSearch extends Product {

    public $cat_id;
    public $order_id;
    public $billing_first_name;
    public $billing_last_name;
    public $billing_email;
    public $billing_address;
    
    public function rules() {
        return [
            [['name', 'description','price','cat_id'], 'safe'],
            [['order_id', 'billing_first_name', 'billing_last_name', 'billing_email', 'billing_address', 'city'], 'safe'],
        ];
    }

    public function scenarios() {
        return Model::scenarios();
    }
    public function search($params) {
        $query = Product::find();
        $dataProvider = new ActiveDataProvider([
            'query' => $query,
            'pagination' => [ 'pageSize' => 5],
            'sort'=> ['defaultOrder' => ['id' => SORT_DESC]]
        ]);
        $this->load($params);
        
        if (!$this->validate()) {
            return $dataProvider;
        }
        $query->joinWith('categoryName');
        $query->andFilterWhere([
            'id' => $this->id,
        ]);
        $query->andFilterWhere(['like', 'name', $this->name])
            ->andFilterWhere(['like', 'description', $this->description])
            ->andFilterWhere(['like', 'price', $this->price])
            ->andFilterWhere(['like', 'category.cat_name', $this->cat_id]);
                
        return $dataProvider;
    }
    public function getorders($params) {
        $query = (new \yii\db\Query)
                ->from('billingdetails');
        $dataProvider = new ActiveDataProvider([
            'query' => $query,
            'pagination' => ['pageSize' => 5],
            'sort' => ['attributes' => ['order_id','billing_first_name', 'billing_last_name', 'billing_email', 'billing_address']]
        ]);
        $this->load($params);

        if (!$this->validate()) {
            return $dataProvider;
        }
        $query->andFilterWhere([
            'id' => $this->id,
        ]);
        $query->andFilterWhere(['like', 'order_id', $this->order_id])
                ->andFilterWhere(['like', 'billing_first_name', $this->billing_first_name])
                ->andFilterWhere(['like', 'billing_last_name', $this->billing_last_name])
                ->andFilterWhere(['like', 'billing_email', $this->billing_email])
                ->andFilterWhere(['like', 'billing_address', $this->billing_address]);
        return $dataProvider;
    }

}
